==> aws-java-sdk-1.3.30-sources.jar: com/amazonaws/services/dynamodb/model/DeleteRequest.java <==
/*
 * Copyright 2010-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.dynamodb.model;

/**
 * <p>
 * A container for a Delete BatchWrite request
 * </p>
 */
public class DeleteRequest {

    /**
     * The item's key to be delete
     */
    private Key key;

    /**
     * The item's key to be delete
     *
     * @return The item's key to be delete
     */
    public Key getKey() {
        return key;
    }
    
    /**
     * The item's key to be delete
     *
     * @param key The item's key to be delete
     */
    public void setKey(Key key) {
        this.key = key;
    }
    
    /**
     * The item's key to be delete
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param key The item's key to be delete
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public DeleteRequest withKey(Key key) {
        this.key = key;
        return this;
    }
    
    
    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getKey() != null) sb.append("Key: " + getKey() + ", ");
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getKey() == null) ? 0 : getKey().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof DeleteRequest == false) return false;
        DeleteRequest other = (DeleteRequest)obj;
        
        if (other.getKey() == null ^ this.getKey() == null) return false;
        if (other.getKey() != null && other.getKey().equals(this.getKey()) == false) return false; 
        return true;
    }
    
}

==> aws-java-sdk-1.4.1-sources.jar: com/amazonaws/services/dynamodb/model/DeleteRequest.java <==
/*
 * Copyright 2010-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.dynamodb.model;
import java.io.Serializable;

/**
 * <p>
 * A container for a Delete BatchWrite request
 * </p>
 */
public class DeleteRequest  implements Serializable  {

    /**
     * The item's key to be delete
     */
    private Key key;

    /**
     * The item's key to be delete
     *
     * @return The item's key to be delete
     */
    public Key getKey() {
        return key;
    }
    
    /**
     * The item's key to be delete
     *
     * @param key The item's key to be delete
     */
    public void setKey(Key key) {
        this.key = key;
    }
    
    /**
     * The item's key to be delete
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param key The item's key to be delete
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public DeleteRequest withKey(Key key) {
        this.key = key;
        return this;
    }
    
    
    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getKey() != null) sb.append("Key: " + getKey() + ", ");
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getKey() == null) ? 0 : getKey().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof DeleteRequest == false) return false;
        DeleteRequest other = (DeleteRequest)obj;
        
        if (other.getKey() == null ^ this.getKey() == null) return false;
        if (other.getKey() != null && other.getKey().equals(this.getKey()) == false) return false; 
        return true;
    }
    
}
